
package com.gridnine.sabre.dqb.stl;

import java.io.Serializable;

/** 
 * Schema fragment(s) for this class:
 * <pre>
 * &lt;xs:group xmlns:ns="http://services.sabre.com/STL/v01" xmlns:xs="http://www.w3.org/2001/XMLSchema" name="SuccessOrErrorCG">
 *   &lt;xs:choice>
 *     &lt;xs:element type="ns:Success" name="Success"/>
 *     &lt;xs:element type="ns:ProblemInformation" name="Error"/>
 *   &lt;/xs:choice>
 * &lt;/xs:group>
 * </pre>
 */
public class SuccessOrErrorCG implements Serializable
{
    private int choiceSelect = -1;
    private static final int SUCCESS_CHOICE = 0;
    private static final int ERROR_CHOICE = 1;
    private Success success;
    private ProblemInformation error;

    private void setChoiceSelect(int choice) {
        if (choiceSelect == -1) {
            choiceSelect = choice;
        } else if (choiceSelect != choice) {
            throw new IllegalStateException(
                    "Need to call clearChoiceSelect() before changing existing choice");
        }
    }

    /** 
     * Clear the choice selection.
     */
    public void clearChoiceSelect() {
        choiceSelect = -1;
    }

    /** 
     * Check if Success is current selection for choice.
     * 
     * @return <code>true</code> if selection, <code>false</code> if not
     */
    public boolean ifSuccess() {
        return choiceSelect == SUCCESS_CHOICE;
    }

    /** 
     * Get the 'Success' element value. Success is an empty element with no children which indicates that the request was processed successfully.
     * 
     * @return value
     */
    public Success getSuccess() {
        return success;
    }

    /** 
     * Set the 'Success' element value. Success is an empty element with no children which indicates that the request was processed successfully.
     * 
     * @param success
     */
    public void setSuccess(Success success) {
        setChoiceSelect(SUCCESS_CHOICE);
        this.success = success;
    }

    /** 
     * Check if Error is current selection for choice.
     * 
     * @return <code>true</code> if selection, <code>false</code> if not
     */
    public boolean ifError() {
        return choiceSelect == ERROR_CHOICE;
    }

    /** 
     * Get the 'Error' element value.
     * 
     * @return value
     */
    public ProblemInformation getError() {
        return error;
    }

    /** 
     * Set the 'Error' element value.
     * 
     * @param error
     */
    public void setError(ProblemInformation error) {
        setChoiceSelect(ERROR_CHOICE);
        this.error = error;
    }
}
